@@ -1,2 +1,2 @@
 # This line of code will allow shorter imports
-from dsa_alg.algorithm import Search
\ No newline at end of file
+from dsa_alg.search import Search
\ No newline at end of file
